@@ -41,11 +41,13 @@
 #' dplyr::count(austen, title)
 #'
 #' @export
-gutenberg_download <- function(gutenberg_id,
-                               mirror = NULL,
-                               strip = TRUE,
-                               meta_fields = character(),
-                               verbose = TRUE) {
+gutenberg_download <- function(
+  gutenberg_id,
+  mirror = gutenberg_get_mirror(verbose = verbose),
+  strip = TRUE,
+  meta_fields = character(),
+  verbose = TRUE
+) {
   url <- gutenberg_url(gutenberg_id, mirror, verbose)
   downloaded <- purrr::map(url, try_gutenberg_download)
   downloaded <- purrr::discard(downloaded, is.null)
